@@ -6,7 +6,7 @@ use std::{
 use yaml_peg::{dump, parse};
 
 /// Reformat the project.
-pub fn fmt<P: AsRef<Path>>(path: P, dry: bool, project: &str) -> Result<()> {
+pub(crate) fn fmt<P: AsRef<Path>>(path: P, dry: bool, project: &str) -> Result<()> {
     let path = path.as_ref().join(project);
     let (yaml, _) = match parse(&read_to_string(&path)?) {
         Ok(v) => v,
