@@ -1,13 +1,13 @@
 use super::Error;
 use std::collections::HashMap;
-use yaml_peg::Node;
+use yaml_peg::{Anchors, Node};
 
 pub(crate) struct FragMap(HashMap<String, HashMap<usize, String>>);
 
 impl FragMap {
-    pub(crate) fn new(slide: &Node, count: &mut usize) -> Result<Self, Error> {
+    pub(crate) fn new(slide: &Node, v: &Anchors, count: &mut usize) -> Result<Self, Error> {
         let mut frag_map = HashMap::new();
-        for h in slide.get_default("fragment", vec![], Node::as_array)? {
+        for h in slide.with(v, "fragment", vec![], Node::as_array)? {
             for (k, v) in h.as_map()?.iter() {
                 let k = k.as_str()?;
                 let v = v.as_str()?;
