@@ -12,60 +12,51 @@ pub(crate) fn slides(
     for (i, slide) in slides.iter().enumerate() {
         let slide = slide.as_anchor(v);
         doc += "<section>";
-        doc += &slide_block(&slide, v, &bg, i == 0)?;
+        doc += &slide_block(slide, v, &bg)?;
         for slide in slide.get_default("sub", vec![], Node::as_array)? {
-            doc += &slide_block(&slide.as_anchor(v), v, &bg, false)?;
+            doc += &slide_block(slide.as_anchor(v), v, &bg)?;
         }
         if i == 0 {
-            if let Some(n) = visible_title(&slide, v) {
+            if let Some(n) = visible_title(slide, v) {
                 title += n.as_str()?;
             }
             if !outline || slides.len() < 2 {
                 continue;
             }
-            doc += "<section data-visibility=\"uncounted\"";
+            doc += "<section";
             if bg.is_valid() {
                 doc += &bg.attr();
             }
-            doc += "><h2>Outline</h2><hr/><ul>";
+            doc += "><h2>Outline</h2><hr/>";
+            let mut outline = String::new();
             for (i, slide) in slides.iter().enumerate() {
                 if i == 0 {
                     continue;
                 }
                 if let Some(n) = visible_title(slide, v) {
-                    doc += &format!("<li><a href=\"#/{}\">", i);
-                    doc += n.as_str()?;
-                    doc += "</a></li>";
+                    outline += &format!("+ [{}](#/{})\n", n.as_str()?, i);
                 } else {
                     continue;
                 }
-                let sub = slide.get_default("sub", vec![], Node::as_array)?;
-                if sub.is_empty() {
-                    continue;
-                }
-                doc += "<ul>";
-                for (j, slide) in sub.iter().enumerate() {
+                for (j, slide) in slide
+                    .get_default("sub", vec![], Node::as_array)?
+                    .iter()
+                    .enumerate()
+                {
                     if let Some(n) = visible_title(slide, v) {
-                        doc += &format!("<li><a href=\"#/{}/{}\">", i, j + 1);
-                        doc += n.as_str()?;
-                        doc += "</a></li>";
+                        outline += &format!("  + [{}](#/{}/{})\n", n.as_str()?, i, j + 1);
                     }
                 }
-                doc += "</ul>";
             }
-            doc += "</ul></section>";
+            doc += &md2html(&outline);
+            doc += "</section>";
         }
         doc += "</section>";
     }
     Ok((doc, title))
 }
 
-fn slide_block(
-    slide: &Node,
-    v: &Anchors,
-    bg: &Background,
-    first_column: bool,
-) -> Result<String, Error> {
+fn slide_block(slide: &Node, v: &Anchors, bg: &Background) -> Result<String, Error> {
     if slide.as_map()?.is_empty() {
         return Err(Error("empty slide", slide.pos()));
     }
@@ -87,19 +78,14 @@ fn slide_block(
         let local_bg = Background::new(slide)?;
         doc += &if local_bg.is_valid() { &local_bg } else { bg }.attr();
     }
+    doc += ">";
     for (i, &title) in ["title", "-title", "$title"].iter().enumerate() {
         if let Ok(n) = slide.get(title) {
-            if first_column || i == 2 {
-                doc += " data-visibility=\"uncounted\"";
-            }
-            doc += ">";
             if i != 1 {
                 doc += &md2html(&format!("# {}", n.as_anchor(v).as_str()?));
                 doc += "<hr/>";
             }
             break;
-        } else if i == 2 {
-            doc += ">";
         }
     }
     doc += &content_block(slide, v, &mut 0)?;
